==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/jmc.pl <==
{
  am_pm_abbreviated => [
    "utuko",
    "kyiukonyi"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "jmc",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Jpi"
  ],
  day_format_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "J"
  ],
  day_format_wide => [
    "Jumatatuu",
    "Jumanne",
    "Jumatanu",
    "Alhamisi",
    "Ijumaa",
    "Jumamosi",
    "Jumapilyi"
  ],
  day_stand_alone_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Jpi"
  ],
  day_stand_alone_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "J"
  ],
  day_stand_alone_wide => [
    "Jumatatuu",
    "Jumanne",
    "Jumatanu",
    "Alhamisi",
    "Ijumaa",
    "Jumamosi",
    "Jumapilyi"
  ],
  era_abbreviated => [
    "KK",
    "BK"
  ],
  era_narrow => [
    "KK",
    "BK"
  ],
  era_wide => [
    "Kabla ya Kristu",
    "Baada ya Kristu"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Machame",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ago",
    "Sep",
    "Okt",
    "Nov",
    "Des"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Aprilyi",
    "Mei",
    "Junyi",
    "Julyai",
    "Agusti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Desemba"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ago",
    "Sep",
    "Okt",
    "Nov",
    "Des"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Aprilyi",
    "Mei",
    "Junyi",
    "Julyai",
    "Agusti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Desemba"
  ],
  name => "Machame",
  native_language => "Kimachame",
  native_name => "Kimachame",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Robo 1",
    "Robo 2",
    "Robo 3",
    "Robo 4"
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Robo 1",
    "Robo 2",
    "Robo 3",
    "Robo 4"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/jmc.pl <==
{
  am_pm_abbreviated => [
    "utuko",
    "kyiukonyi",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "jmc",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Jpi",
  ],
  day_format_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "J",
  ],
  day_format_wide => [
    "Jumatatuu",
    "Jumanne",
    "Jumatanu",
    "Alhamisi",
    "Ijumaa",
    "Jumamosi",
    "Jumapilyi",
  ],
  day_stand_alone_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Jpi",
  ],
  day_stand_alone_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "J",
  ],
  day_stand_alone_wide => [
    "Jumatatuu",
    "Jumanne",
    "Jumatanu",
    "Alhamisi",
    "Ijumaa",
    "Jumamosi",
    "Jumapilyi",
  ],
  era_abbreviated => [
    "KK",
    "BK",
  ],
  era_narrow => [
    "KK",
    "BK",
  ],
  era_wide => [
    "Kabla ya Kristu",
    "Baada ya Kristu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Machame",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ago",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Aprilyi",
    "Mei",
    "Junyi",
    "Julyai",
    "Agusti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Desemba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ago",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Aprilyi",
    "Mei",
    "Junyi",
    "Julyai",
    "Agusti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Desemba",
  ],
  name => "Machame",
  native_language => "Kimachame",
  native_name => "Kimachame",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Robo 1",
    "Robo 2",
    "Robo 3",
    "Robo 4",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Robo 1",
    "Robo 2",
    "Robo 3",
    "Robo 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
